SpotlightDurationConfig class

Constructors

SpotlightDurationConfig({Duration zoomIn = const Duration(milliseconds: 600), Duration zoomOut = const Duration(milliseconds: 600), Duration bump = const Duration(milliseconds: 500), Duration contentFadeIn = const Duration(milliseconds: 200)})
const

Properties

bump Duration
Duration for bump forward and reverse.
final
contentFadeIn Duration
Duration of fading in the content after zoom-in.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zoomIn Duration
Duration for zoom in the spotlight (start).
final
zoomOut Duration
Duration for zoom out the spotlight (finish).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

zero → const SpotlightDurationConfig