ContentPreferLayout enum
- Inheritance
- Available extensions
Values
- vertical → const ContentPreferLayout
-
it will choose Alignment.topCenter or Alignment.bottomCenter
- horizontal → const ContentPreferLayout
-
it will choose Alignment.centerLeft or Alignment.centerRight
- largerRatio → const ContentPreferLayout
-
it will choose the larger ratio compare to window's ratio
For example, target is at
(0.7 * window_width, 0.4 * window_height)it will align to Alignment.centerLeft, since|0.7 - 0.5| > |0.4 - 0.5|
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isPreferHorizontal(
double xRatio, double yRatio) → bool -
Available on ContentPreferLayout, provided by the PreferLayoutExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ContentPreferLayout> - A constant List of the values in this enum, in order of their declaration.